const path = require('path');
const TerserPlugin = require("terser-webpack-plugin");

module.exports = {
  entry: './src/index.js',
  output: {
    filename: 'swoop.js',
    path: path.resolve(__dirname, "dist"),
    sourceMapFilename: "swoop.js.map",
    libraryTarget: "umd",
    umdNamedDefine: true,
    //https://stackoverflow.com/questions/53683089/webpack-4-library-target-umd-x-is-not-a-constructor
    libraryExport: 'default',
    library: "Swoop"
  },
  module: {
    rules: [{
        test: /\.js$/,
        exclude: /node_modules/,
        use: {
          loader: 'babel-loader'
        }
      },
      {
        test: /\.css$/,
        use: [
          { loader: 'style-loader' },
          {
            loader: 'css-loader'
          },
        ]
      },
      {
        test: /\.(png|svg|jpg|gif|jpe?g)$/,
        use: [{
          options: {
            name: "[name].[ext]",
            outputPath: "assets/"
          },
          loader: "file-loader"
        }]
      }
    ]
  },
  optimization: {
    minimize: true,
    minimizer: [new TerserPlugin()]
  },
  devServer: {
    disableHostCheck: true,
    contentBase: path.resolve(__dirname, 'dist'),
    publicPath: '/assets/',
    port: 3001
  }
}